@@ -4,7 +4,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2020-2023 Univention GmbH
+# Copyright 2020-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -34,15 +34,10 @@
 
 from copy import deepcopy
 
+from unittest.mock import MagicMock
 from univentionunittests.udm_filter import make_filter
 
 
-try:
-    from mock import MagicMock
-except ImportError:
-    from unittest.mock import MagicMock
-
-
 def get_domain():
     return 'dc=intranet,dc=example,dc=de'
 
