@@ -4,7 +4,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2020-2023 Univention GmbH
+# Copyright 2020-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -78,8 +78,7 @@ class Database(object):
                 self.add(obj)
 
     def __iter__(self):
-        for obj in self.objs.values():
-            yield obj
+        yield from self.objs.values()
 
     def __repr__(self):
         return 'Database({!r})'.format(self.objs)
